#[derive(StableId)]Expand description
Derives all traits introduced by the stable-id-traits crate.
The struct should be a tuple which contains an unsigned numeric primitive type.
#[derive(StableId)]Derives all traits introduced by the stable-id-traits crate.
The struct should be a tuple which contains an unsigned numeric primitive type.